// urlExtract.es
//
// Demonstrate the use of the PAM with ECMAScripting
// that looks at file products and extracts fully qualified
// URLs from them.
//
// Requires: JavaAccess, BasicIO, FileIO

// First define some shortcuts - note that partially expanded
// package names can be assigned. 

PAM = Packages.org.mitre.pam;

// input arguments as named variables:
//   agent = instance of ScriptFilter juggler
//   product = product received by ScriptFilter juggler

if (product == null) {
	writeln ("no product to process");
	return null;
}

visitor = new PAM.productVisitor.AsFlatFileList();
visitor.visit(product);
e = visitor.getFileProductList();
if (!e.hasMoreElements()) {
	return null;
}

if (!loadExtension('FESI.Extensions.OptionalRegExp')) {
   writeln("RegExp NOT loaded");
   return null;
}

urlPattern = new RegExp( "\\w+://([\\w.]+)/[^\\s\"']+/?" );

urls = new Array();

count = 0;
while (e.hasMoreElements()) {
 prod = e.nextElement();
 content = prod.getContent();
 if (content == null) continue;
 name = content.getFile();
 file = File(name);
 file.open();
 while ((s = file.readln()) != null && s != file.eof()) {
  while ((result = urlPattern.exec(s)) != null) {
   url = result[0];
   // writeln("Matched '", url, "' at position ", result.index);
   if (!urls[url]) {
	count++;
	urls[url] = 1;
   }
   s = s.substring(result.index + url.length);
  }
 }

 file.close();
}

writeln (count, " urls");

if (count == 0) {
	writeln ("no urls");
	return null;
}

if (count == 1) {
	bp = new PAM.product.view.BasicProduct("URL Test", "");
	bp.setContent(new java.net.URL(url));
	return bp;
}

vp = new PAM.product.view.VectorProduct("URL List Test", "list of URLs");

for (url in urls) {
   bp = new PAM.product.view.BasicProduct(url, "");
   bp.setContent(new java.net.URL(url));
   vp.addElement(bp);
}

return vp;
